write method
Converts object to a String by invoking Object.toString and
adds the encoding of the result to the target consumer.
This operation is non-blocking. See flush or done for how to get any errors generated by this call.
Implementation
@override
void write(Object? object) {
if (ApiLogService().isEnabled) {
final string = object.toString();
_bodyBytes.addAll(utf8.encode(string));
}
_inner.write(object);
}