writeAll method

  1. @override
void writeAll(
  1. Iterable objects, [
  2. String separator = ""
])
override

Iterates over the given objects and writes them in sequence.

If separator is provided, a write with the separator is performed between any two elements of objects.

This operation is non-blocking. See flush or done for how to get any errors generated by this call.

Implementation

@override
void writeAll(Iterable objects, [String separator = ""]) {
  if (ApiLogService().isEnabled) {
    for (var obj in objects) {
      write(obj);
      if (separator.isNotEmpty) write(separator);
    }
  } else {
    _inner.writeAll(objects, separator);
  }
}