ApiLogModel class

Constructors

ApiLogModel({required String id, required String sessionId, required String method, required String url, Map<String, String>? requestHeaders, dynamic requestBody, Map<String, String>? responseHeaders, dynamic responseBody, int? statusCode, required DateTime timestamp, required Duration duration, String? screenName, bool isError = false})
ApiLogModel.fromMap(Map<String, dynamic> map)
factory

Properties

duration Duration
final
formattedDateTime String
no setter
formattedDuration String
no setter
formattedRequestBody String
no setter
formattedRequestHeaders String
no setter
formattedResponseBody String
no setter
formattedResponseHeaders String
no setter
formattedTime String
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
final
isError bool
final
method String
final
requestBody → dynamic
final
requestHeaders Map<String, String>?
final
responseBody → dynamic
final
responseHeaders Map<String, String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenName String?
final
sessionId String
final
statusCode int?
final
timestamp DateTime
final
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited