RecipientConfig class
Properties
-
email
→ String
-
The email address of the recipient.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
name
→ String
-
The display name of the recipient (e.g., 'QA Team').
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited