ApiLogService class
Constructors
- ApiLogService()
-
factory
Properties
- currentSessionId → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEnabled → bool
-
no setter
- isInitialized → bool
-
no setter
- lastSenderName → String?
-
no setter
-
logStream
→ Stream<
List< ApiLogModel> > -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- smtpConfig → SmtpConfig?
-
no setter
Methods
-
addLog(
ApiLogModel log) → Future< void> -
clearAll(
) → Future< void> -
clearSession(
String sessionId) → Future< void> -
disable(
) → Future< void> -
enable(
) → Future< void> -
getCurrentSessionLogs(
) → List< ApiLogModel> -
getLogCountForSession(
String sessionId) → Future< int> -
getLogsForSession(
String sessionId) → Future< List< ApiLogModel> > -
getSessions(
) → Future< List< ApiSessionModel> > -
init(
) → Future< void> - Load persisted state and start a new session if enabled.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setLastSenderName(
String name) → Future< void> -
setSmtpConfig(
SmtpConfig? config) → void -
toString(
) → String -
A string representation of this object.
inherited
-
updateSessionName(
String sessionId, String newName) → Future< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited